@@ -1,10 +1,9 @@
-use v5.16; # from dependencies, so go for it.
 package CPAN::Mini::Inject;
 
 use strict;
 use warnings;
 
-use CPAN::Checksums 2.13;
+use CPAN::Checksums 2.13 qw( updatedir );
 use CPAN::Mini;
 use CPAN::Mini::Inject::Config;
 use Carp;
@@ -13,57 +12,16 @@ use File::Basename;
 use File::Copy;
 use File::Path qw( make_path );
 use File::Spec;
-use File::Spec::Functions;
-use File::Temp qw(tempfile);
 use LWP::Simple;
 use Dist::Metadata ();
 
-BEGIN {
-  use version 0.9915;
-  use CPAN::Meta::Converter;
-
-  # This is here because the CPAN::Meta package has not been updated
-  # since 2016 and it's unlikely that they'd accept a patch for this.
-  # see https://github.com/briandfoy/cpan-mini-inject/issues/11
-  # and https://github.com/Perl-Toolchain-Gang/CPAN-Meta#138
-  package # hide from PAUSE
-    CPAN::Meta::Converter;
-
-  no warnings qw(redefine);
-
-  # lifted from CPAN::Meta::Converter
-  # https://fastapi.metacpan.org/source/DAGOLDEN/CPAN-Meta-2.150010/lib/CPAN/Meta/Converter.pm
-  sub _clean_version {
-    my ($element) = @_;
-    return 0 if ! defined $element;
-
-    $element =~ s{^\s*}{};
-    $element =~ s{\s*$}{};
-    $element =~ s{^\.}{0.};
-
-    return 0 if ! length $element;
-    return 0 if ( $element eq 'undef' || $element eq '<undef>' );
-    my $v = eval { version->parse($element) };
-    # XXX check defined $v and not just $v because version objects leak memory
-    # in boolean context -- dagolden, 2012-02-03
-    if ( defined $v ) {
-    return _is_qv($v) ? $v->stringify : $element;
-    }
-    else {
-    return 0;
-    }
-  }
-}
-
-=encoding utf8
-
 =head1 NAME
 
 CPAN::Mini::Inject - Inject modules into a CPAN::Mini mirror.
 
 =cut
 
-our $VERSION = '1.009_01';
+our $VERSION = '1.002';
 our @ISA     = qw( CPAN::Mini );
 
 =head1 SYNOPSIS
@@ -76,12 +34,10 @@ probably want to look at the L<mcpani> command instead.
     $mcpi=CPAN::Mini::Inject->new;
     $mcpi->parsecfg('t/.mcpani/config');
 
-    $mcpi->add(
-      module   => 'CPAN::Mini::Inject',
-    authorid => 'SSORICHE',
-    version  => ' 0.01',
-    file     => 'mymodules/CPAN-Mini-Inject-0.01.tar.gz'
-  );
+    $mcpi->add( module   => 'CPAN::Mini::Inject',
+                authorid => 'SSORICHE',
+                version  => ' 0.01',
+                file     => 'mymodules/CPAN-Mini-Inject-0.01.tar.gz' )
 
     $mcpi->writelist;
     $mcpi->update_mirror;
@@ -122,59 +78,45 @@ Create a new CPAN::Mini::Inject object.
 =cut
 
 sub new {
-  my( $class, %args ) = @_;
-  my %defaults = (
-    config_class => $class->default_config_class,
-  );
-  my %allowed = map {
-    $_, 1
-  } qw(config_class);
-
-  my %filtered =
-    map { ($_, $args{$_}) }
-    grep { exists $allowed{$_} }
-    keys %args;
-
-
-  my %obj = ( %defaults, %filtered );
-  return bless \%obj, $class;
+  return bless
+   { config_class => 'CPAN::Mini::Inject::Config' },
+   $_[0];
 }
 
 =item C<< config_class( [CLASS] ) >>
 
-Returns the name of the class used to handle the configuration. Also
-see C<default_config_class>.
+Returns the name of the class handling the configuration.
+
+With an argument, it sets the name of the class to handle
+the config. To use that, you'll have to call it before you
+load the configuration.
 
 =cut
 
 sub config_class {
   my $self = shift;
+
   if ( @_ ) { $self->{config_class} = shift }
+
   $self->{config_class};
 }
 
-=item C<< config( [HASHREF] ) >>
+=item C<< config >>
 
-With a hashref argument, sets the config data.
-
-Returns the current configuration hash.
+Returns the configuration object. This object should be from
+the class returned by C<config_class> unless you've done something
+weird.
 
 =cut
 
 sub config {
   my $self = shift;
+
   if ( @_ ) { $self->{config} = shift }
+
   $self->{config};
 }
 
-=item C<< default_config_class >>
-
-=cut
-
-sub default_config_class {
-  'CPAN::Mini::Inject::Config'
-}
-
 =item C<< loadcfg( [FILENAME] ) >>
 
 
@@ -215,9 +157,8 @@ sub parsecfg {
 
 =item C<< site( [SITE] ) >>
 
-With an argument, set the site to use to contact CPAN. Returns the
-site setting, or, if the site has not be set (or was set to undef),
-returns the empty string.
+Returns the CPAN site that CPAN::Mini::Inject chose from the
+list specified in the C<remote> directive.
 
 =cut
 
@@ -227,15 +168,14 @@ sub site {
 
   if ( @_ ) { $self->{site} = shift }
 
-  $self->{site} // '';
+  $self->{site} || '';
 }
 
 =item C<testremote>
 
-Test each site listed in the remote parameter of the config file by
-performing a get on each site in order for authors/01mailrc.txt.gz.
-The first site to respond successfully is set as the instance variable
-site.
+Test each site listed in the remote parameter of the config file by performing
+a get on each site in order for authors/01mailrc.txt.gz. The first site to
+respond successfully is set as the instance variable site.
 
  print "$mcpi->{site}\n"; # ftp://ftp.cpan.org/pub/CPAN
 
@@ -285,16 +225,11 @@ sub update_mirror {
 
   $ENV{FTP_PASSIVE} = 1 if $self->config->get( 'passive' );
 
-  $options{local}        ||= $self->config->get( 'local' );
-  $options{trace}        ||= 0;
-  $options{skip_perl}    ||= $self->config->get( 'perl' ) || 1;
+  $options{local}     ||= $self->config->get( 'local' );
+  $options{trace}     ||= 0;
+  $options{skip_perl} ||= $self->config->get( 'perl' ) || 1;
   $options{skip_cleanup} ||= $self->config->get( 'skip_cleanup' ) || 0;
 
-  # module_filters, log_level, and force
-  my @extra = grep { defined $self->config->get($_) } qw(module_filters log_level force);
-
-  $options{$_} = $self->config->get($_) for @extra;
-
   $self->testremote( $options{trace} )
    unless ( $self->site || $options{remote} );
   $options{remote} ||= $self->site;
@@ -307,53 +242,48 @@ sub update_mirror {
 
 =item C<add>
 
-Add a new distribution to the repository. The C<add> method copies the
-distribution file into the repository with the same structure as a
-CPAN site. For example, F<CPAN-Mini-Inject-0.01.tar.gz> with author
-C<SSORICHE> is copied to F<MYCPAN/authors/id/S/SS/SSORICHE>. add
-creates the required directory structure below the repository.
+Add a new module to the repository. The add method copies the module
+file into the repository with the same structure as a CPAN site. For
+example CPAN-Mini-Inject-0.01.tar.gz is copied to
+MYCPAN/authors/id/S/SS/SSORICHE. add creates the required directory
+structure below the repository.
 
 Packages found in the distribution will be added to the module list
-(for example both C<CPAN::Mini::Inject> and
-C<CPAN::Mini::Inject::Config> will be added to the
-F<modules/02packages.details.txt.gz> file).
+(for example both C<CPAN::Mini::Inject> and C<CPAN::Mini::Inject::Config>
+will be added to the F<modules/02packages.details.txt.gz> file).
 
-Packages will be looked for in the C<provides> key of the META file if
-present, otherwise the files in the dist will be searched. See
-L<Dist::Metadata> for more information.
+Packages will be looked for in the C<provides> key of the META file if present,
+otherwise the files in the dist will be searched.
+See L<Dist::Metadata> for more information.
 
 =over 4
 
 =item * module
 
-(optional) The package name of the module to add. The distribution
-file will be searched for modules but you can specify the main one
-explicitly.
+The name of the module to add.
+The distribution file will be searched for modules
+but you can specify the main one explicitly.
 
 =item * authorid
 
-(required) The CPAN ID of the module's author. Since this isn't
-actually CPAN, the ID does not need to exist on CPAN. Typically, this
-ID uses C<[A-Z]> and is three to ten letters. This is not enforced,
-but other CPAN tools may not like other sorts of names.
+CPAN author id. This does not have to be a real author id.
 
 =item * version
 
-(optional) The module's version number. If you don't specify this.
-C<add> will try to extract it from the distribution.
+The modules version number.
+Module names and versions will be determined,
+but you can specify one explicitly.
 
 =item * file
 
-(required) The path to the distribution file.
+The tar.gz of the module.
 
 =back
 
-  $mcpani->add(
-    module   => 'Module::Name',
-  authorid => 'SOMEAUTHOR',
-  version  => 0.01,
-  file     => './Module-Name-0.01.tar.gz'
-  );
+  add( module => 'Module::Name',
+       authorid => 'AUTHOR',
+       version => 0.01,
+       file => './Module-Name-0.01.tar.gz' );
 
 =cut
 
@@ -376,10 +306,10 @@ sub add {
 
   # attempt to guess module and version
   my $distmeta = Dist::Metadata->new( file => $options{file} );
-
   my $packages = $distmeta->package_versions;
-  # include passed in module and version (prefer the declared version)
-  if ( $options{module} and $options{version} ) {
+
+  # include passed in module and version (prefer discovered version)
+  if ( $options{module} ) {
     $packages->{ $options{module} } ||= $options{version};
   }
 
@@ -513,11 +443,11 @@ sub inject {
   }
 
   for my $dir ( keys( %updatedir ) ) {
-    my $root    = catfile( $self->config->get( 'local' ), qw(authors id) );
-    my $authdir = catfile( $root, $dir );
+    my $root    = $self->config->get( 'local' ) . "/authors/id";
+    my $authdir = "$root/$dir";
 
-    CPAN::Checksums::updatedir( $authdir, $root );
-    $self->_updperms( catfile($authdir, 'CHECKSUMS') );
+    updatedir( $authdir, $root );
+    $self->_updperms( "$authdir/CHECKSUMS" );
   }
 
   $self->updpackages;
@@ -571,7 +501,10 @@ sub updauthors {
   AUTHOR:
   for my $modline ( @{ $self->{modulelist} } ) {
     my ( $module, $version, $file ) = split( /\s+/, $modline );
-    my $author = (File::Spec->splitdir( $file ))[2];
+
+    # extract the author from the path
+    my @dirs = File::Spec->splitdir( $file );
+    my $author = $dirs[2];
 
     next AUTHOR if defined $author_ids_in_repo{$author};
     next AUTHOR if defined $authors_added{$author};
@@ -721,40 +654,36 @@ sub _readpkgs {
 }
 
 sub _writepkgs {
-  my( $self, $pkgs ) = @_;
+  my $self = shift;
+  my $pkgs = shift;
 
-  my $dest = catfile(
-    $self->config->get( 'local' ),
-    'modules',
-    '02packages.details.txt.gz'
+  my $gzwrite = gzopen(
+    $self->config->get( 'local' )
+     . '/modules/02packages.details.txt.gz', 'wb'
+   )
+   or croak
+   "Can't open local 02packages.details.txt.gz for writing: $gzerrno";
+
+  $gzwrite->gzwrite( "File:         02packages.details.txt\n" );
+  $gzwrite->gzwrite(
+    "URL:          http://www.perl.com/CPAN/modules/02packages.details.txt\n"
   );
-
-  my($fh, $temp_filename) = tempfile();
-
-  my $gzwrite = gzopen($fh, 'wb')
-   or croak "Can't open local 02packages.details.txt.gz for writing: $gzerrno";
-
-  my @headers = (
-    [ 'File'         => '02packages.details.txt'                                  ],
-    [ 'URL'          => 'http://www.perl.com/CPAN/modules/02packages.details.txt' ],
-    [ 'Description'  => 'Package names found in directory $CPAN/authors/id/'      ],
-    [ 'Columns'      => 'package name, version, path'                             ],
-    [ 'Intended-For' => 'Automated fetch routines, namespace documentation.'      ],
-    [ 'Written-By'   => "CPAN::Mini::Inject $VERSION"                             ],
-    [ 'Line-Count'   => scalar( @$pkgs )                                          ],
-    [ 'Last-Updated' => _fmtdate()                                                ],
+  $gzwrite->gzwrite(
+    'Description:  Package names found in directory $CPAN/authors/id/'
+     . "\n" );
+  $gzwrite->gzwrite( "Columns:      package name, version, path\n" );
+  $gzwrite->gzwrite(
+    "Intended-For: Automated fetch routines, namespace documentation.\n"
   );
-
-  foreach my $header ( @headers ) {
-    $gzwrite->gzwrite(sprintf "%-13s %s\n", $header->[0] . ':', $header->[1]);
-  }
-  $gzwrite->gzwrite("\n");
+  $gzwrite->gzwrite( "Written-By:   CPAN::Mini::Inject $VERSION\n" );
+  $gzwrite->gzwrite( "Line-Count:   " . scalar( @$pkgs ) . "\n" );
+  # Last-Updated: Sat, 19 Mar 2005 19:49:10 GMT
+  $gzwrite->gzwrite( "Last-Updated: " . _fmtdate() . "\n\n" );
 
   $gzwrite->gzwrite( "$_\n" ) for ( @$pkgs );
 
   $gzwrite->gzclose;
 
-  copy( $temp_filename, $dest ) or croak "copying 02packages failed: $!";
 }
 
 sub _readauthors {
@@ -821,7 +750,7 @@ Thanks to Jozef Kutej <jozef@kutej.net> for numerous patches.
 
 Report issues to the GitHub queue at
 
-  https://github.com/briandfoy/cpan-mini-inject/issues
+	https://github.com/briandfoy/cpan-mini-inject/issues
 
 =head1 COPYRIGHT AND LICENSE
 
